@@ -4,28 +4,27 @@ for reading and writing data in NWB format
 import os.path
 from copy import deepcopy
 from warnings import warn
-
 import h5py
 
+from hdmf.spec import NamespaceCatalog
+from hdmf.utils import docval, getargs, popargs, call_docval_func, get_docval
+from hdmf.backends.io import HDMFIO
+from hdmf.backends.hdf5 import HDF5IO as _HDF5IO
+from hdmf.validate import ValidatorMap
+from hdmf.build import BuildManager, TypeMap
+import hdmf.common
+
+
 CORE_NAMESPACE = 'core'
-
-from hdmf.spec import NamespaceCatalog  # noqa: E402
-from hdmf.utils import docval, getargs, popargs, call_docval_func  # noqa: E402
-from hdmf.backends.io import HDMFIO  # noqa: E402
-from hdmf.backends.hdf5 import HDF5IO as _HDF5IO  # noqa: E402
-from hdmf.validate import ValidatorMap  # noqa: E402
-from hdmf.build import BuildManager  # noqa: E402
-
-from .spec import NWBDatasetSpec, NWBGroupSpec, NWBNamespace  # noqa: E402
-
 __core_ns_file_name = 'nwb.namespace.yaml'
 
+from .spec import NWBDatasetSpec, NWBGroupSpec, NWBNamespace  # noqa E402
+
 
 def __get_resources():
     from pkg_resources import resource_filename
-    from os.path import join
     ret = dict()
-    ret['namespace_path'] = join(resource_filename(__name__, 'data'), __core_ns_file_name)
+    ret['namespace_path'] = os.path.join(resource_filename(__name__, 'nwb-schema/core'), __core_ns_file_name)
     return ret
 
 
@@ -40,13 +39,15 @@ global __TYPE_MAP
 
 __NS_CATALOG = NamespaceCatalog(NWBGroupSpec, NWBDatasetSpec, NWBNamespace)
 
-from hdmf.build import TypeMap as TypeMap  # noqa: E402
+hdmf_typemap = hdmf.common.get_type_map()
+__NS_CATALOG.merge(hdmf_typemap.namespace_catalog)
 
 __TYPE_MAP = TypeMap(__NS_CATALOG)
+__TYPE_MAP.merge(hdmf_typemap)
 
 
 @docval({'name': 'extensions', 'type': (str, TypeMap, list),
-         'doc': 'a path to a namespace, a TypeMap, or a list consisting paths to namespaces and TypeMaps',
+         'doc': 'a path to a namespace, a TypeMap, or a list consisting of paths to namespaces and TypeMaps',
          'default': None},
         returns="the namespaces loaded from the given file", rtype=tuple,
         is_method=False)
@@ -71,8 +72,7 @@ def get_type_map(**kwargs):
                 elif isinstance(ext, TypeMap):
                     type_map.merge(ext)
                 else:
-                    msg = 'extensions must be a list of paths to namespace specs or a TypeMaps'
-                    raise ValueError(msg)
+                    raise ValueError('extensions must be a list of paths to namespace specs or a TypeMaps')
         elif isinstance(extensions, str):
             type_map.load_namespaces(extensions)
         elif isinstance(extensions, TypeMap):
@@ -80,9 +80,7 @@ def get_type_map(**kwargs):
     return type_map
 
 
-@docval({'name': 'extensions', 'type': (str, TypeMap, list),
-         'doc': 'a path to a namespace, a TypeMap, or a list consisting paths to namespaces and TypeMaps',
-         'default': None},
+@docval(*get_docval(get_type_map),
         returns="the namespaces loaded from the given file", rtype=tuple,
         is_method=False)
 def get_manager(**kwargs):
@@ -94,8 +92,7 @@ def get_manager(**kwargs):
     return BuildManager(type_map)
 
 
-@docval({'name': 'namespace_path', 'type': str,
-         'doc': 'the path to the YAML with the namespace definition'},
+@docval({'name': 'namespace_path', 'type': str, 'doc': 'the path to the YAML with the namespace definition'},
         returns="the namespaces loaded from the given file", rtype=tuple,
         is_method=False)
 def load_namespaces(**kwargs):
@@ -113,14 +110,15 @@ if os.path.exists(__resources['namespace_path']):
 
 
 def available_namespaces():
+    """Returns all namespaces registered in the namespace catalog"""
     return __NS_CATALOG.namespaces
 
 
 # a function to register a container classes with the global map
 @docval({'name': 'neurodata_type', 'type': str, 'doc': 'the neurodata_type to get the spec for'},
         {'name': 'namespace', 'type': str, 'doc': 'the name of the namespace'},
-        {"name": "container_cls", "type": type,
-         "doc": "the class to map to the specified neurodata_type", 'default': None},
+        {"name": "container_cls", "type": type, "doc": "the class to map to the specified neurodata_type",
+         'default': None},
         is_method=False)
 def register_class(**kwargs):
     """Register an NWBContainer class to use for reading and writing a neurodata_type from a specification
@@ -140,13 +138,13 @@ def register_class(**kwargs):
 
 # a function to register an object mapper for a container class
 @docval({"name": "container_cls", "type": type,
-         "doc": "the Container class for which the given ObjectMapper class gets used for"},
+         "doc": "the Container class for which the given ObjectMapper class gets used"},
         {"name": "mapper_cls", "type": type, "doc": "the ObjectMapper class to use to map", 'default': None},
         is_method=False)
 def register_map(**kwargs):
     """Register an ObjectMapper to use for a Container class type
-    If mapper_cls is not specified, returns a decorator for registering an ObjectMapper class
-    as the mapper for container_cls. If mapper_cls specified, register the class as the mapper for container_cls
+    If mapper_cls is not specified, returns a decorator for registering an ObjectMapper class as the mapper for
+    container_cls. If mapper_cls is specified, register the class as the mapper for container_cls
     """
     container_cls, mapper_cls = getargs('container_cls', 'mapper_cls', kwargs)
 
@@ -159,22 +157,18 @@ def register_map(**kwargs):
         _dec(mapper_cls)
 
 
-# a function to get the container class for a give type
-@docval({'name': 'neurodata_type', 'type': str,
-         'doc': 'the neurodata_type to get the NWBConatiner class for'},
+@docval({'name': 'neurodata_type', 'type': str, 'doc': 'the neurodata_type to get the NWBContainer class for'},
         {'name': 'namespace', 'type': str, 'doc': 'the namespace the neurodata_type is defined in'},
         is_method=False)
 def get_class(**kwargs):
-    """Get the class object of the NWBContainer subclass corresponding to a given neurdata_type.
+    """Get the class object of the NWBContainer subclass corresponding to a given neurodata_type.
     """
     neurodata_type, namespace = getargs('neurodata_type', 'namespace', kwargs)
     return __TYPE_MAP.get_container_cls(namespace, neurodata_type)
 
 
-@docval({'name': 'io', 'type': HDMFIO,
-         'doc': 'the HDMFIO object to read from'},
-        {'name': 'namespace', 'type': str,
-         'doc': 'the namespace to validate against', 'default': CORE_NAMESPACE},
+@docval({'name': 'io', 'type': HDMFIO, 'doc': 'the HDMFIO object to read from'},
+        {'name': 'namespace', 'type': str, 'doc': 'the namespace to validate against', 'default': CORE_NAMESPACE},
         returns="errors in the file", rtype=list,
         is_method=False)
 def validate(**kwargs):
@@ -195,8 +189,8 @@ class NWBHDF5IO(_HDF5IO):
              'default': False},
             {'name': 'manager', 'type': BuildManager, 'doc': 'the BuildManager to use for I/O', 'default': None},
             {'name': 'extensions', 'type': (str, TypeMap, list),
-             'doc': 'a path to a namespace, a TypeMap, or a list consisting paths \
-             to namespaces and TypeMaps', 'default': None},
+             'doc': 'a path to a namespace, a TypeMap, or a list consisting paths to namespaces and TypeMaps',
+             'default': None},
             {'name': 'file', 'type': h5py.File, 'doc': 'a pre-existing h5py.File object', 'default': None},
             {'name': 'comm', 'type': "Intracomm", 'doc': 'the MPI communicator to use for parallel I/O',
              'default': None})
@@ -235,7 +229,7 @@ class NWBHDF5IO(_HDF5IO):
 from . import io as __io  # noqa: F401,E402
 from .core import NWBContainer, NWBData  # noqa: F401,E402
 from .base import TimeSeries, ProcessingModule  # noqa: F401,E402
-from .file import NWBFile  # noqa: E402, F401
+from .file import NWBFile  # noqa: F401,E402
 
 from . import behavior  # noqa: F401,E402
 from . import device  # noqa: F401,E402
