@@ -3,12 +3,13 @@ try:
 except ImportError:
     from collections import Iterable  # Python 2.7
 
-from hdmf.utils import docval, getargs, popargs, call_docval_func
+from hdmf.utils import docval, getargs, popargs, call_docval_func, get_docval
 from hdmf.data_utils import DataChunkIterator, assertEqualShape
 
 from . import register_class, CORE_NAMESPACE
-from .base import TimeSeries, _default_resolution, _default_conversion
-from .core import NWBContainer, NWBDataInterface, MultiContainerInterface, DynamicTableRegion
+from .base import TimeSeries
+from .core import NWBContainer, NWBDataInterface, MultiContainerInterface
+from hdmf.common import DynamicTableRegion
 from .device import Device
 
 
@@ -25,9 +26,7 @@ class ElectrodeGroup(NWBContainer):
     @docval({'name': 'name', 'type': str, 'doc': 'the name of this electrode'},
             {'name': 'description', 'type': str, 'doc': 'description of this electrode group'},
             {'name': 'location', 'type': str, 'doc': 'description of location of this electrode group'},
-            {'name': 'device', 'type': Device, 'doc': 'the device that was used to record from this electrode group'},
-            {'name': 'parent', 'type': 'NWBContainer',
-             'doc': 'The parent NWBContainer for this NWBContainer', 'default': None})
+            {'name': 'device', 'type': Device, 'doc': 'the device that was used to record from this electrode group'})
     def __init__(self, **kwargs):
         call_docval_func(super(ElectrodeGroup, self).__init__, kwargs)
         description, location, device = popargs("description", "location", "device", kwargs)
@@ -36,20 +35,6 @@ class ElectrodeGroup(NWBContainer):
         self.device = device
 
 
-_et_docval = [
-    {'name': 'id', 'type': int, 'doc': 'a unique identifier for the electrode'},
-    {'name': 'x', 'type': float, 'doc': 'the x coordinate of the position'},
-    {'name': 'y', 'type': float, 'doc': 'the y coordinate of the position'},
-    {'name': 'z', 'type': float, 'doc': 'the z coordinate of the position'},
-    {'name': 'imp', 'type': float, 'doc': 'the impedance of the electrode'},
-    {'name': 'location', 'type': str, 'doc': 'the location of electrode within the subject e.g. brain region'},
-    {'name': 'filtering', 'type': str, 'doc': 'description of hardware filtering'},
-    {'name': 'description', 'type': str, 'doc': 'a brief description of what this electrode is'},
-    {'name': 'group', 'type': ElectrodeGroup, 'doc': 'the ElectrodeGroup object to add to this NWBFile'},
-    {'name': 'group_name', 'type': str, 'doc': 'the ElectrodeGroup object to add to this NWBFile', 'default': None}
-]
-
-
 @register_class('ElectricalSeries', CORE_NAMESPACE)
 class ElectricalSeries(TimeSeries):
     """
@@ -59,42 +44,30 @@ class ElectricalSeries(TimeSeries):
     """
 
     __nwbfields__ = ({'name': 'electrodes', 'required_name': 'electrodes',
-                      'doc': 'the electrodes that generated this electrical series', 'child': True},)
+                      'doc': 'the electrodes that generated this electrical series', 'child': True},
+                     'channel_conversion')
 
-    __help = "Stores acquired voltage data from extracellular recordings."
-
-    @docval({'name': 'name', 'type': str, 'doc': 'The name of this TimeSeries dataset'},
-            {'name': 'data', 'type': ('array_data', 'data', TimeSeries),
+    @docval(*get_docval(TimeSeries.__init__, 'name'),  # required
+            {'name': 'data', 'type': ('array_data', 'data', TimeSeries),  # required
              'shape': ((None, ), (None, None), (None, None, None)),
              'doc': 'The data this TimeSeries dataset stores. Can also store binary data e.g. image frames'},
-
-            {'name': 'electrodes', 'type': DynamicTableRegion,
+            {'name': 'electrodes', 'type': DynamicTableRegion,  # required
              'doc': 'the table region corresponding to the electrodes from which this series was recorded'},
-            {'name': 'resolution', 'type': float,
-             'doc': 'The smallest meaningful difference (in specified unit) between values in data',
-             'default': _default_resolution},
-            {'name': 'conversion', 'type': float,
-             'doc': 'Scalar to multiply each element by to convert to volts', 'default': _default_conversion},
-
-            {'name': 'timestamps', 'type': ('array_data', 'data', TimeSeries),
-             'doc': 'Timestamps for samples stored in data', 'default': None},
-            {'name': 'starting_time', 'type': float, 'doc': 'The timestamp of the first sample', 'default': None},
-            {'name': 'rate', 'type': float, 'doc': 'Sampling rate in Hz', 'default': None},
-
-            {'name': 'comments', 'type': str,
-             'doc': 'Human-readable comments about this TimeSeries dataset', 'default': 'no comments'},
-            {'name': 'description', 'type': str,
-             'doc': 'Description of this TimeSeries dataset', 'default': 'no description'},
-            {'name': 'control', 'type': Iterable,
-             'doc': 'Numerical labels that apply to each element in data', 'default': None},
-            {'name': 'control_description', 'type': Iterable,
-             'doc': 'Description of each control value', 'default': None},
-            {'name': 'parent', 'type': 'NWBContainer',
-             'doc': 'The parent NWBContainer for this NWBContainer', 'default': None})
+            {'name': 'channel_conversion', 'type': ('array_data', 'data'), 'shape': (None,), 'doc':
+             "Channel-specific conversion factor. Multiply the data in the 'data' dataset by these values along the "
+             "channel axis (as indicated by axis attribute) AND by the global conversion factor in the 'conversion' "
+             "attribute of 'data' to get the data values in Volts, i.e, data in Volts = data * data.conversion * "
+             "channel_conversion. This approach allows for both global and per-channel data conversion factors needed "
+             "to support the storage of electrical recordings as native values generated by data acquisition systems. "
+             "If this dataset is not present, then there is no channel-specific conversion factor, i.e. it is 1 for all"
+             " channels.", 'default': None},
+            *get_docval(TimeSeries.__init__, 'resolution', 'conversion', 'timestamps', 'starting_time', 'rate',
+                        'comments', 'description', 'control', 'control_description'))
     def __init__(self, **kwargs):
-        name, electrodes, data = popargs('name', 'electrodes', 'data', kwargs)
-        super(ElectricalSeries, self).__init__(name, data, 'volt', **kwargs)
+        name, electrodes, data, channel_conversion = popargs('name', 'electrodes', 'data', 'channel_conversion', kwargs)
+        super(ElectricalSeries, self).__init__(name, data, 'volts', **kwargs)
         self.electrodes = electrodes
+        self.channel_conversion = channel_conversion
 
 
 @register_class('SpikeEventSeries', CORE_NAMESPACE)
@@ -111,35 +84,17 @@ class SpikeEventSeries(ElectricalSeries):
 
     __nwbfields__ = ()
 
-    __help = "Snapshots of spike events from data."
-
-    @docval({'name': 'name', 'type': str, 'doc': 'The name of this TimeSeries dataset'},
-            {'name': 'data', 'type': ('array_data', 'data', TimeSeries),
-             'doc': 'The data this TimeSeries dataset stores. Can also store binary data e.g. image frames'},
-            {'name': 'timestamps', 'type': ('array_data', 'data', TimeSeries),
+    @docval(*get_docval(ElectricalSeries.__init__, 'name', 'data'),  # required
+            {'name': 'timestamps', 'type': ('array_data', 'data', TimeSeries),  # required
              'doc': 'Timestamps for samples stored in data'},
-            {'name': 'electrodes', 'type': DynamicTableRegion,
-             'doc': 'the table region corresponding to the electrodes from which this series was recorded'},
-            {'name': 'resolution', 'type': float,
-             'doc': 'The smallest meaningful difference (in specified unit) between values in data',
-             'default': _default_resolution},
-            {'name': 'conversion', 'type': float,
-             'doc': 'Scalar to multiply each element by to convert to volts', 'default': _default_conversion},
-            {'name': 'comments', 'type': str,
-             'doc': 'Human-readable comments about this TimeSeries dataset', 'default': 'no comments'},
-            {'name': 'description', 'type': str,
-             'doc': 'Description of this TimeSeries dataset', 'default': 'no description'},
-            {'name': 'control', 'type': Iterable,
-             'doc': 'Numerical labels that apply to each element in data', 'default': None},
-            {'name': 'control_description', 'type': Iterable,
-             'doc': 'Description of each control value', 'default': None},
-            {'name': 'parent', 'type': 'NWBContainer',
-             'doc': 'The parent NWBContainer for this NWBContainer', 'default': None})
+            *get_docval(ElectricalSeries.__init__, 'electrodes'),  # required
+            *get_docval(ElectricalSeries.__init__, 'resolution', 'conversion', 'comments', 'description', 'control',
+                        'control_description'))
     def __init__(self, **kwargs):
         name, data, electrodes = popargs('name', 'data', 'electrodes', kwargs)
         timestamps = getargs('timestamps', kwargs)
-        if not (isinstance(data, TimeSeries) and isinstance(timestamps, TimeSeries)):
-            if not (isinstance(data, DataChunkIterator) and isinstance(timestamps, DataChunkIterator)):
+        if not (isinstance(data, TimeSeries) or isinstance(timestamps, TimeSeries)):
+            if not (isinstance(data, DataChunkIterator) or isinstance(timestamps, DataChunkIterator)):
                 if len(data) != len(timestamps):
                     raise Exception('Must provide the same number of timestamps and spike events')
             else:
@@ -159,18 +114,15 @@ class EventDetection(NWBDataInterface):
                      'source_idx',
                      'times')
 
-    __help = ("Description of how events were detected, such as voltage "
-              "threshold, or dV/dT threshold, as well as relevant values.")
-
     @docval({'name': 'detection_method', 'type': str,
-             'doc': 'Description of how events were detected, such as voltage threshold, or dV/dT threshold, \
-             as well as relevant values.'},
+             'doc': 'Description of how events were detected, such as voltage threshold, or dV/dT threshold, '
+             'as well as relevant values.'},
             {'name': 'source_electricalseries', 'type': ElectricalSeries, 'doc': 'The source electrophysiology data'},
             {'name': 'source_idx', 'type': ('array_data', 'data'),
-             'doc': 'Indices (zero-based) into source ElectricalSeries::data array corresponding \
-             to time of event. Module description should define what is meant by time of event \
-             (e.g., .25msec before action potential peak, zero-crossing time, etc). \
-             The index points to each event from the raw data'},
+             'doc': 'Indices (zero-based) into source ElectricalSeries::data array corresponding '
+                    'to time of event. Module description should define what is meant by time of event '
+                    '(e.g., .25msec before action potential peak, zero-crossing time, etc). '
+                    'The index points to each event from the raw data'},
             {'name': 'times', 'type': ('array_data', 'data'), 'doc': 'Timestamps of events, in Seconds'},
             {'name': 'name', 'type': str, 'doc': 'the name of this container', 'default': 'EventDetection'})
     def __init__(self, **kwargs):
@@ -178,11 +130,10 @@ class EventDetection(NWBDataInterface):
             'detection_method', 'source_electricalseries', 'source_idx', 'times', kwargs)
         super(EventDetection, self).__init__(**kwargs)
         self.detection_method = detection_method
-        # do not set parent, since this is a link
         self.source_electricalseries = source_electricalseries
         self.source_idx = source_idx
         self.times = times
-        self.unit = 'Seconds'
+        self.unit = 'seconds'
 
 
 @register_class('EventWaveform', CORE_NAMESPACE)
@@ -200,8 +151,6 @@ class EventWaveform(MultiContainerInterface):
         'create': 'create_spike_event_series'
     }
 
-    __help = "Waveform of detected extracellularly recorded spike events"
-
 
 @register_class('Clustering', CORE_NAMESPACE)
 class Clustering(NWBDataInterface):
@@ -218,16 +167,13 @@ class Clustering(NWBDataInterface):
         'times'
     )
 
-    __help = ("[DEPRECATED] Clustered spike data, whether from automatic clustering "
-              "tools (eg, klustakwik) or as a result of manual sorting.")
-
     @docval({'name': 'description', 'type': str,
-             'doc': 'Description of clusters or clustering, (e.g. cluster 0 is noise, \
-             clusters curated using Klusters, etc).'},
+             'doc': 'Description of clusters or clustering, (e.g. cluster 0 is noise, '
+                    'clusters curated using Klusters, etc).'},
             {'name': 'num', 'type': ('array_data', 'data'), 'doc': 'Cluster number of each event.', 'shape': (None, )},
             {'name': 'peak_over_rms', 'type': Iterable, 'shape': (None, ),
-             'doc': 'Maximum ratio of waveform peak to RMS on any channel in the cluster\
-             (provides a basic clustering metric).'},
+             'doc': 'Maximum ratio of waveform peak to RMS on any channel in the cluster'
+                    '(provides a basic clustering metric).'},
             {'name': 'times', 'type': ('array_data', 'data'), 'doc': 'Times of clustered events, in seconds.',
              'shape': (None,)},
             {'name': 'name', 'type': str, 'doc': 'the name of this container', 'default': 'Clustering'})
@@ -259,10 +205,6 @@ class ClusterWaveforms(NWBDataInterface):
                      'waveform_mean',
                      'waveform_sd')
 
-    __help = ("[DEPRECATED] Mean waveform shape of clusters. Waveforms should be "
-              "high-pass filtered (ie, not the same bandpass filter "
-              "used waveform analysis and clustering)")
-
     @docval({'name': 'clustering_interface', 'type': Clustering,
              'doc': 'the clustered spike data used as input for computing waveforms'},
             {'name': 'waveform_filtering', 'type': str,
@@ -270,7 +212,7 @@ class ClusterWaveforms(NWBDataInterface):
             {'name': 'waveform_mean', 'type': Iterable, 'shape': (None, None),
              'doc': 'the mean waveform for each cluster'},
             {'name': 'waveform_sd', 'type': Iterable, 'shape': (None, None),
-            'doc': 'the standard deviations of waveforms for each cluster'},
+             'doc': 'the standard deviations of waveforms for each cluster'},
             {'name': 'name', 'type': str, 'doc': 'the name of this container', 'default': 'ClusterWaveforms'})
     def __init__(self, **kwargs):
         import warnings
@@ -299,9 +241,6 @@ class LFP(MultiContainerInterface):
          'get': 'get_electrical_series',
          'create': 'create_electrical_series'}]
 
-    __help = ("LFP data from one or more channels. Filter properties "
-              "should be noted in the ElectricalSeries")
-
 
 @register_class('FilteredEphys', CORE_NAMESPACE)
 class FilteredEphys(MultiContainerInterface):
@@ -316,10 +255,6 @@ class FilteredEphys(MultiContainerInterface):
     electrode may have different filtered (e.g., theta and/or gamma) signals represented.
     """
 
-    __help = ("Ephys data from one or more channels that is subjected to filtering, such as "
-              "for gamma or theta oscillations (LFP has its own interface). Filter properties should "
-              "be noted in the ElectricalSeries")
-
     __clsconf__ = {
         'attr': 'electrical_series',
         'type': ElectricalSeries,
@@ -341,8 +276,6 @@ class FeatureExtraction(NWBDataInterface):
                      'times',
                      'features')
 
-    __help = "Container for salient features of detected events"
-
     @docval({'name': 'electrodes', 'type': DynamicTableRegion,
              'doc': 'the table region corresponding to the electrodes from which this series was recorded'},
             {'name': 'description', 'type': ('array_data', 'data'),
